summaryrefslogtreecommitdiffstats
path: root/kword/KWFrameView.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 06:08:18 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 06:08:18 +0000
commitb6edfe41c9395f2e20784cbf0e630af6426950a3 (patch)
tree56ed9b871d4296e6c15949c24e16420be1b28697 /kword/KWFrameView.h
parentef39e8e4178a8f98cf5f154916ba0f03e4855206 (diff)
downloadkoffice-b6edfe41c9395f2e20784cbf0e630af6426950a3.tar.gz
koffice-b6edfe41c9395f2e20784cbf0e630af6426950a3.zip
rename the following methods:
tqfind find tqreplace replace tqcontains contains git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1246075 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kword/KWFrameView.h')
-rw-r--r--kword/KWFrameView.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kword/KWFrameView.h b/kword/KWFrameView.h
index d4dcabde..d7b63aba 100644
--- a/kword/KWFrameView.h
+++ b/kword/KWFrameView.h
@@ -105,7 +105,7 @@ public:
/// returns if the @p point is on the border
bool isBorderHit(const KoPoint &point) const;
/// returns if the @p point is anywhere in te frame, if fuzzy is true; also a little outside
- bool tqcontains(const KoPoint &point, bool fuzzy = true) const;
+ bool contains(const KoPoint &point, bool fuzzy = true) const;
/**
* Return the MouseMeaning enum value for the tqparent view.
@@ -138,7 +138,7 @@ public:
private:
/**
* Helper method for isBorderHit() and tqcontains()
* @param point the point
* @param borderOnly if true; exclude the range inside the frame
* @param fuzzy don't take all the coordinates too strict, allow for some margin
@@ -138,7 +138,7 @@ public:
private:
/**
- * Helper method for isBorderHit() and tqcontains()
+ * Helper method for isBorderHit() and contains()
* @param point the point
* @param borderOnly if true; exclude the range inside the frame